@@ -1,21 +1,21 @@
-## package umap
-## calculations via the umap python package
-##
-## part of this implementation was inspired by https://github.com/ropenscilabs/umapr
+# package umap
+# calculations via the umap python package
+#
+# part of this implementation was inspired by https://github.com/ropenscilabs/umapr
 
 
 
-##' Create a umap embedding using python package umap-learn
-##'
-##' @keywords internal
-##' @param d data object
-##' @param config list with settings
-##'
-##' @return list, one element of which is matrix with embedding coordinates
+#' Create a umap embedding using python package umap-learn
+#'
+#' @keywords internal
+#' @param d data object
+#' @param config list with settings
+#'
+#' @return list, one element of which is matrix with embedding coordinates
 umap.learn = function(d, config) {
   check.learn.available()
 
-  ## get an update config object that includes a vector of arguments for umap-learn
+  # get an update config object that includes a vector of arguments for umap-learn
   config = detect.umap.learn(config)
 
   message.w.date(paste0("calling umap-learn (v", config$umap_learn_version, ")"),
@@ -23,13 +23,13 @@ umap.learn = function(d, config) {
   message.w.date(paste0("setting arguments: ", length(config$umap_learn_args)),
                  config$verbose)
   
-  ## adjust values in config to please python type checkers
+  # adjust values in config to please python type checkers
   if (is.na(config$random_state)) {
     config$random_state= as.integer(stats::runif(1, 0, 2^30))
   }
   config$verbose = 0+as.logical(config$verbose)
 
-  ## construct python object and create embedding
+  # construct python object and create embedding
   wo.NA = names(config[!is.na(config)])
   UMAP = do.call(python.umap$UMAP, config[intersect(wo.NA, config$umap_learn_args)])
   embedding = UMAP$fit_transform(d)
@@ -40,29 +40,27 @@ umap.learn = function(d, config) {
 }
 
 
-
-
-##' predict embedding of new data given an existing umap object
-##'
-##' @keywords internal
-##' @param umap object of class umap
-##' @param data matrix with new data
-##'
-##' @return matrix with embedding coordinates
+#' predict embedding of new data given an existing umap object
+#'
+#' @keywords internal
+#' @param umap object of class umap
+#' @param data matrix with new data
+#'
+#' @return matrix with embedding coordinates
 umap.learn.predict = function(umap, data) {
   check.learn.available()
 
   if (!"UMAP" %in% names(umap)) {
     umap.error("component UMAP is not available")
   }
-  if (!"umap.umap_.UMAP" %in% class(umap$UMAP)) {
+  if (!is(umap$UMAP, "umap.umap_.UMAP")) {
     umap.error("components UMAP is corrupt")
   }
-
+  
   config = detect.umap.learn(umap$config)
   message.w.date(paste0("calling umap-learn (v", config$umap_learn_version, ")"),
                  config$verbose)
-  ## perform the fit
+  # perform the fit
   embedding = umap$UMAP$transform(data)
   rownames(embedding) = rownames(data)
   message.w.date("done", config$verbose)
@@ -71,18 +69,16 @@ umap.learn.predict = function(umap, data) {
 }
 
 
+# ############################################################################
+# Helper functions 
 
 
-## ############################################################################
-## Helper functions 
-
-
-##' adjust config depending on umap-learn version
-##'
-##' @keywords internal
-##' @param config list with settings
-##'
-##' @return config list with set umap_learn_args
+#' adjust config depending on umap-learn version
+#'
+#' @keywords internal
+#' @param config list with settings
+#'
+#' @return config list with set umap_learn_args
 detect.umap.learn = function(config) {
   
   if (!identical(config$umap_learn_args, NA)) {
@@ -91,7 +87,7 @@ detect.umap.learn = function(config) {
   
   learn.version = as.character(python.umap$"__version__")
   config$umap_learn_version = learn.version
-  ## get a main version number from the detail version
+  # get a main version number from the detail version
   main.version = paste(strsplit(learn.version, "\\.")[[1]][1:2], collapse=".")
   
   args.version = list(
@@ -121,9 +117,8 @@ detect.umap.learn = function(config) {
 }
 
 
-
-##' check whether python module is available, abort if not
-##' @keywords internal
+#' check whether python module is available, abort if not
+#' @keywords internal
 check.learn.available = function() {
   if (is.null(python.umap)) {
     umap.error("python package umap-learn is not available")
